[Sie-announce] SIEコード [2593] SVGColorのテストを追加

Back to archive index

svnno****@sourc***** svnno****@sourc*****
2011年 4月 15日 (金) 23:39:11 JST


Revision: 2593
          http://sourceforge.jp/projects/sie/svn/view?view=rev&revision=2593
Author:   dhrname
Date:     2011-04-15 23:39:11 +0900 (Fri, 15 Apr 2011)

Log Message:
-----------
SVGColorのテストを追加

Modified Paths:
--------------
    trunk/Spec/spec/SvgDomSpec.js

Modified: trunk/Spec/spec/SvgDomSpec.js
===================================================================
--- trunk/Spec/spec/SvgDomSpec.js	2011-04-15 14:34:01 UTC (rev 2592)
+++ trunk/Spec/spec/SvgDomSpec.js	2011-04-15 14:39:11 UTC (rev 2593)
@@ -1007,13 +1007,14 @@
     });
   });
   describe("SVG Unit :: SVGColor", function() {
-    var s;
+    var s = [];
     beforeEach(function() {
-      s = svg.createSVGNumber();
+      svg.style.setProperty("stop-color", "black")
+      s[s.length] = svg.style.getPropertyCSSValue("stop-color"); //SVGColor型オブジェクトを返す
     });
-    /*デフォルト値かどうかをチェックしていく(Checking the default value of a SVGNumber interface.)*/
-    it("for the default value on the property of SVGNumber", function() {
-      expect(s.value).toEqual(0);
+    /*デフォルト値かどうかをチェックしていく(Checking the default value of a SVGColor interface.)*/
+    it("for the default value on the property of SVGColor", function() {
+      expect(typeof s.rgbColor).toEqual(0);
     });
   });
 });
\ No newline at end of file




Sie-announce メーリングリストの案内
Back to archive index